//deploy vm
import { ApolloClient, createHttpLink, gql, InMemoryCache } from '@apollo/client/core'

export const apolloClient = () => {
  const httpLink = createHttpLink({
    uri: import.meta.env.VITE_APP_GRAPHQL_ENDPOINT,
    credentials: 'include' // Include credentials for cross-origin requests
  })

  const apolloClient = new ApolloClient({
    cache: new InMemoryCache(),
    link: httpLink,
    headers: {
      Accept: 'application/json',
      'Accept-Encoding': 'gzip, deflate',
      'Cache-Control': 'no-cache',
      Connection: 'keep-alive',
      'Content-Type': 'application/json'
      // Add other headers as needed
    }
  })
  return apolloClient
}

export const queries = {
  keluhan:{
    daftar: {
      keluhanSelesaiTanpaIDPelanggan: gql`
        query daftarKeluhanSelesaiTanpaIdPelanggan(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanSelesaiTanpaIdPelanggan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_ulp
            nama_pelapor
            no_laporan
            no_telp_pelapor
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      keluhanDiselesaikanCC123: gql`
        query daftarKeluhanDiselesaikanCC123(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanDiselesaikanCC123(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            idpel_nometer
            jumlah_lapor
            pembuat_laporan
            keterangan_pelapor
            media
            nama_uid
            nama_ulp
            nama_pelapor
            no_laporan
            nama_issuetype
            nama_subissuetype
            no_telp_pelapor
            status_akhir
            waktu_recovery
          }
        }
      `,
      keluhanResponseTime: gql`
        query daftarKeluhanResponseTime(
          $dateFrom: Date!
          $dateTo: Date!
          $minDurasiResponseTime: Int!
          $maxDurasiResponseTime: Int!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanResponseTime(
            dateFrom: $dateFrom
            dateTo: $dateTo
            minDurasiResponseTime: $minDurasiResponseTime
            maxDurasiResponseTime: $maxDurasiResponseTime
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            nama_ulp
            no_laporan
            no_telp_pelapor
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      keluhanRecoveryTime: gql`
        query daftarKeluhanRecoveryTime(
          $dateFrom: Date!
          $dateTo: Date!
          $minDurasiRecoveryTime: Int!
          $maxDurasiRecoveryTime: Int!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanRecoveryTime(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            minDurasiRecoveryTime: $minDurasiRecoveryTime
            maxDurasiRecoveryTime: $maxDurasiRecoveryTime
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            nama_ulp
            no_laporan
            no_telp_pelapor
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      keluhanMelaporLebihDariSatuKali: gql`
        query daftarKeluhanMelaporLebihDariSatuKali(
          $minJmlLapor: Int!
          $maxJmlLapor: Int!
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanMelaporLebihDariSatuKali(
            dateFrom: $dateFrom
            dateTo: $dateTo
            minJmlLapor: $minJmlLapor
            maxJmlLapor: $maxJmlLapor
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            jumlah_lapor
            keterangan_pelapor
            media
            nama_pelapor
            nama_ulp
            no_laporan
            no_telp_pelapor
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      keluhanDipindahkanKeIDULPLain: gql`
        query daftarKeluhanDialihkanKeUnitLain(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanDialihkanKeUnitLain(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            id_unit_baru
            id_unit_lama
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            nama_unit_baru
            nama_unit_lama
            no_laporan
            no_telp_pelapor
            pembuat_laporan
            status_akhir
            waktu_dialihkan
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      keluhanBerdasarkanMedia: gql`
        query daftarKeluhanBerdasarkanMedia(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanBerdasarkanMedia(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            keterangan_pelapor
            media
            waktu_media
            keterangan_media
            waktu_lapor
            nama_pelapor
            no_laporan
            no_telp_pelapor
            nama_ulp
            status_akhir
            waktu_recovery
            waktu_response
          }
        }
      `,
    },
    rekap: {
      keluhanPerRatingUnit: gql`
        query rekapitulasiKeluhanRatingPerUnit(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanRatingPerUnit(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            in_process
            indeks_rating
            jumlah_non_rating
            jumlah_rating
            nama_idUlp
            persen_in_process
            persen_non_rating
            persen_rating
            persen_selesai
            rating_1
            rating_2
            rating_3
            rating_4
            rating_5
            regu
            selesai
            total
          }
        }
      `,
      keluhanPerUnit: gql`
        query rekapitulasiKeluhanPerUnit(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerUnit(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_ulp
            nama_ulp
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            total_durasi_recovery
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPerTanggal :gql`
        query rekapitulasiKeluhanPerTanggal(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerTanggal(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            tanggal_lapor
            total
            total_durasi_response
            total_durasi_recovery
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPerKelompokKeluhan: gql`
        query rekapitulasiKeluhanPerKelompokKeluhan(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerKelompokKeluhan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            kelompok
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_durasi_recovery
            total_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPerJenisKeluhan : gql`
        query rekapitulasiKeluhanPerJenisKeluhan(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerJenisKeluhan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            tipe_keluhan
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_durasi_response
            total_durasi_recovery
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPenyelesaianPerFungsiBIidang :gql`
        query rekapitulasiKeluhanPenyelesaianPerFungsiBidang(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPenyelesaianPerFungsiBidang(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            fungsi_bidang
            total
            total_durasi_response
            total_durasi_recovery
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      rekapKeluhanBerdasarkanMedia: gql`
        query rekapitulasiKeluhanBerdasarkanMedia(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanBerdasarkanMedia(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            media
            tgl1
            tgl10
            tgl11
            tgl12
            tgl13
            tgl14
            tgl15
            tgl16
            tgl17
            tgl18
            tgl19
            tgl2
            tgl20
            tgl21
            tgl22
            tgl23
            tgl24
            tgl25
            tgl26
            tgl27
            tgl28
            tgl29
            tgl3
            tgl30
            tgl31
            tgl4
            tgl5
            tgl6
            tgl7
            tgl8
            tgl9
          }
        }
      `,
      rekapKeluhanAll: gql`
        query rekapitulasiKeluhanAll(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanAll(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_ulp
            nama_ulp
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
    },
  },
  gangguan:{
    rekap: {
      gangguanRatingPerRegu: gql`
        query rekapitulasiGangguanRatingPerRegu(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanRatingPerRegu(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            in_process
            indeks_rating
            jumlah_non_rating
            jumlah_rating
            nama_posko
            persen_in_process
            persen_non_rating
            persen_rating
            persen_selesai
            rating_1
            rating_2
            rating_3
            rating_4
            rating_5
            regu
            selesai
            total
          }
        }
      `,
      gangguanRatingPerPosko : gql`
        query rekapitulasiGangguanRatingPerPosko(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanRatingPerPosko(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            in_process
            indeks_rating
            jumlah_non_rating
            jumlah_rating
            nama_posko
            persen_in_process
            persen_non_rating
            persen_rating
            persen_selesai
            rating_1
            rating_2
            rating_3
            rating_4
            rating_5
            regu
            selesai
            total
          }
        }
      `,
      gangguanPerTanggal: gql`
        query rekapitulasiGangguanPerTanggal(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanPerTanggal(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            nama_posko
            avg_durasi_recovery
            avg_durasi_response
            max_durasi_recovery
            max_durasi_response
            min_durasi_recovery
            min_durasi_response
            persen_inproses
            persen_selesai
            tanggal
            total
            total_durasi_response
            total_durasi_recovery
            total_diatas_sla_recovery
            total_diatas_sla_response
            total_dibawah_sla_recovery
            total_dibawah_sla_response
            total_inproses
            total_selesai
          }
        }
      `,
      gangguanPerRegu: gql`
        query rekapitulasiGangguanPerRegu(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanPerRegu(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            kode_regu
            nama_regu
            avg_durasi_recovery
            avg_durasi_response
            max_durasi_recovery
            max_durasi_response
            min_durasi_recovery
            min_durasi_response
            persen_inproses
            persen_selesai
            nama_posko
            total
            total_durasi_recovery
            total_durasi_response
            total_diatas_sla_recovery
            total_diatas_sla_response
            total_dibawah_sla_recovery
            total_dibawah_sla_response
            total_inproses
            total_selesai
          }
        }
      `,
      gangguanPerPosko: gql`
        query rekapitulasiGangguanPerPosko(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanPerPosko(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            avg_durasi_recovery
            avg_durasi_response
            id_posko
            max_durasi_recovery
            max_durasi_response
            min_durasi_recovery
            min_durasi_response
            nama_posko
            persen_inproses
            persen_selesai
            total
            total_durasi_recovery
            total_durasi_response
            total_diatas_sla_recovery
            total_diatas_sla_response
            total_dibawah_sla_recovery
            total_dibawah_sla_response
            total_inproses
            total_selesai
          }
        }
      `,
      gangguanKoreksiTransaksiIndividual: gql`
        query rekapitulasiGangguanKoreksiTransaksiIndividual(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanKoreksiTransaksiIndividual(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            agustus
            april
            desember
            februari
            januari
            juli
            juni
            maret
            mei
            november
            oktober
            september
            uid
            ulp
            up3
          }
        }
      `,
      jenisGangguanSE004: gql`
        query rekapitulasiJenisGangguanSE004(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiJenisGangguanSE004(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            sub_kelompok
            total
            selesai
            persen_selesai
            in_process
            persen_in_process
            total_durasi_response
            avg_waktu_response_time
            max_durasi_response
            min_durasi_response
            diatas_sla_durasi_response
            dibawah_sla_durasi_response
            total_durasi_recovery
            avg_waktu_recovery_time
            max_durasi_recovery
            min_durasi_recovery
            diatas_sla_durasi_recovery
            dibawah_sla_durasi_recovery
          }
        }
      `,
      jenisGangguan: gql`
        query rekapitulasiPerJenisGangguan(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiPerJenisGangguan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            sub_kelompok
            avg_durasi_recovery
            avg_durasi_response
            max_durasi_recovery
            max_durasi_response
            min_durasi_recovery
            min_durasi_response
            persen_inproses
            persen_selesai
            tipe_permasalahan
            total
            kode
            total_durasi_recovery
            total_durasi_response
            total_diatas_sla_recovery
            total_diatas_sla_response
            total_dibawah_sla_recovery
            total_dibawah_sla_response
            total_inproses
            total_selesai
          }
        }
      `,
      gangguanDiselesaikanMobileAPKT: gql`
        query rekapitulasiGangguanDiselesaikanMobileAPKT(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanDiselesaikanMobileAPKT(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            avg_waktu_recovery_mobile_marking
            avg_waktu_recovery_mobile_nonmarking
            avg_waktu_recovery_nonmobile_marking
            avg_waktu_recovery_nonmobile_nonmarking
            avg_waktu_response_mobile_marking
            avg_waktu_response_mobile_nonmarking
            avg_waktu_response_nonmobile_marking
            avg_waktu_response_nonmobile_nonmarking
            kode_regu
            persen_belum_selesai
            persen_laporan_mobile_marking
            persen_laporan_mobile_nonmarking
            persen_laporan_nonmobile_marking
            persen_laporan_nonmobile_nonmarking
            persen_selesai
            regu
            total_belum_selesai
            total_laporan
            total_laporan_mobile_marking
            total_laporan_mobile_nonmarking
            total_laporan_nonmobile_marking
            total_laporan_nonmobile_nonmarking
            total_selesai
          }
        }
      `,
      rekapGangguanAlihPosko: gql`
        query rekapitulasiGangguanCleansingTransaksiTM(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanCleansingTransaksiTM(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            agustus
            april
            desember
            februari
            januari
            juli
            juni
            maret
            mei
            november
            oktober
            september
            uid
            ulp
            up3
          }
        }
      `,
      berdasarkanMedia: gql`
        query rekapitulasiGangguanBerdasarkanMedia(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanBerdasarkanMedia(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            media
            total
            tgl1
            tgl10
            tgl11
            tgl12
            tgl13
            tgl14
            tgl15
            tgl16
            tgl17
            tgl18
            tgl19
            tgl2
            tgl20
            tgl21
            tgl22
            tgl23
            tgl24
            tgl25
            tgl26
            tgl27
            tgl28
            tgl29
            tgl3
            tgl30
            tgl31
            tgl4
            tgl5
            tgl6
            tgl7
            tgl8
            tgl9
          }
        }
      `,
      gangguanAll: gql`
        query rekapitulasiAllGangguan(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiAllGangguan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            avg_durasi_dispatch
            avg_durasi_recovery
            avg_durasi_response
            max_durasi_dispatch
            max_durasi_recovery
            max_durasi_response
            min_durasi_dispatch
            min_durasi_recovery
            min_durasi_response
            persen_inproses
            persen_selesai
            nama_posko
            total
            total_diatas_sla_dispatch
            total_diatas_sla_recovery
            total_diatas_sla_response
            total_dibawah_sla_dispatch
            total_dibawah_sla_recovery
            total_dibawah_sla_response
            total_inproses
            total_selesai
          }
        }
      `,
      gangguanAlihPosko: gql`
        query rekapitulasiGangguanAlihPosko(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanAlihPosko(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_posko
            id_uid
            id_up3
            nama_posko
            nama_uid
            nama_up3
            posko_in
            posko_out
          }
        }
      `,
    },
    daftar: {
      selesaiTanpaIDPelanggan: gql`
        query daftarGangguanSelesaiTanpaIdPelanggan(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarGangguanSelesaiTanpaIdPelanggan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            no_laporan
            no_telp_pelapor
            nama_posko
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      responseTime: gql`
        query daftarGangguanResponseTime(
          $dateFrom: Date!
          $dateTo: Date!
          $minDurasiResponseTime: Int!
          $maxDurasiResponseTime: Int!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarGangguanResponseTime(
            dateFrom: $dateFrom
            dateTo: $dateTo
            minDurasiResponseTime: $minDurasiResponseTime
            maxDurasiResponseTime: $maxDurasiResponseTime
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            penyebab
            referensi_marking
            tindakan
            nama_pelapor
            is_marking
            no_laporan
            no_telp_pelapor
            nama_posko
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      recoveryTime: gql`
        query daftarGangguanRecoveryTime(
          $dateFrom: Date!
          $dateTo: Date!
          $minDurasiRecoveryTime: Int!
          $maxDurasiRecoveryTime: Int!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarGangguanRecoveryTime(
            dateFrom: $dateFrom
            dateTo: $dateTo
            minDurasiRecoveryTime: $minDurasiRecoveryTime
            maxDurasiRecoveryTime: $maxDurasiRecoveryTime
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            no_laporan
            referensi_marking
            no_telp_pelapor
            nama_posko
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      melaporLebihDariSatuKali: gql`
        query gangguan(
          $minJmlLapor: Int!
          $maxJmlLapor: Int!
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarGangguanMelaporLebihDariSatuKali(
            minJmlLapor: $minJmlLapor
            maxJmlLapor: $maxJmlLapor
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            pembuat_laporan
            durasi_response_time
            durasi_recovery_time
            idpel_nometer
            jumlah_lapor
            keterangan_pelapor
            media
            nama_pelapor
            no_laporan
            no_telp_pelapor
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
            nama_posko
          }
        }
      `,
      diselesaikanMobileAPKT: gql`
        query daftarGangguanDiselesaikanMobileAPKT(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarGangguanDiselesaikanMobileAPKT(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            no_laporan
            no_telp_pelapor
            nama_posko
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      dataDialihkanKePoskoLain: gql`
        query DaftarGangguan($dateFrom: Date!, $dateTo: Date!, $posko: Int, $idUid: Int, $idUp3: Int) {
          daftarGangguanDialihkanKePoskoLain(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            pembuat_laporan
            durasi_recovery_time
            durasi_response_time
            waktu_lapor
            waktu_dialihkan
            waktu_recovery
            waktu_response
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            no_laporan
            no_telp_pelapor
            nama_posko_lama
            nama_posko_baru
            status_akhir
            waktu_recovery
            waktu_response
          }
        }
      `,
      berdasarkanMedia: gql`
        query daftarGangguanBerdasarkanMedia(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String!
        ) {
          daftarGangguanBerdasarkanMedia(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
            media: $media
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            no_laporan
            no_telp_pelapor
            nama_posko
            status_akhir
            waktu_media
            waktu_lapor
            waktu_recovery
            waktu_response
            keterangan_media
          }
        }
      `
    },
  },
  monalisa: {
    gangguan: {
      rekap: {
        dispatchingTimeGangguan: gql`
          query DaftarmonalisaDispatchingTimeGangguan(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaDispatchingTimeGangguan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        rekapitulasiEnsGangguan: gql`
          query DaftarmonalisaRekapitulasiEnsGangguan(
            #$regional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaRekapitulasiEnsGangguan(
              #regional: $regional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        gangguanBelumSelesai: gql`
          query DaftarmonalisaGangguanBelumSelesai(
            #$regional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaGangguanBelumSelesai(
              #regional: $regional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              jumlah_gangguan
              jumlah_informasi
              total
            }
          }
        `,
        gangguanPerJenisGangguan: gql`
          query DaftarmonalisaGangguanPerJenisGangguan(
            #$nama_regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaGangguanPerJenisGangguan(
              #nama_regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              id_jenis_gangguan
              nama_jenis_gangguan
              jumlah
              persen
            }
          }
        `,
        jumlahDurasiRptRctGangguan: gql`
          query DaftarmonalisaJumlahDurasiRptRctGangguan(
            #$regional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaJumlahDurasiRptRctGangguan(
              #regional: $regional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              total_durasi_response_time_bulan_ini
              count_durasi_response_time_bulan_ini
              avg_durasi_response_time_bulan_ini
              total_durasi_recovery_time_bulan_ini
              count_durasi_recovery_time_bulan_ini
              avg_durasi_recovery_time_bulan_ini
              total_durasi_response_time_tahun_ini
              count_durasi_response_time_tahun_ini
              avg_durasi_response_time_tahun_ini
              total_durasi_recovery_time_tahun_ini
              count_durasi_recovery_time_tahun_ini
              avg_durasi_recovery_time_tahun_ini
            }
          }
        `,
        jumlahKaliGangguan: gql`
          query DaftarMonalisaJumlahKaliGangguan(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaJumlahKaliGangguan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_uid
              nama_up3
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        laporUlangGangguan: gql`
          query DaftarmonalisaRekapitulasiLaporUlangGangguan(
            #$regional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaRekapitulasiLaporUlangGangguan(
              #regional: $regional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        recoveryTimeGangguan: gql`
          query DaftarmonalisaRecoveryTimeGangguan(
            #$regional: regional
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaRecoveryTimeGangguan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        responseTimeGangguan: gql`
          query DaftarmonalisaResponseTimeGangguan(
            #regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaResponseTimeGangguan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `
      }
    },
    keluhan: {
      rekap: {
        jumlahKaliKeluhan: gql`
          query DaftarMonalisaJumlahKaliKeluhan(
            #$regional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaJumlahKaliKeluhan(
              #regional: $regional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        recoveryTimeKeluhan: gql`
          query DaftarmonalisaRecoveryTimeKeluhan(
            #$regional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaRecoveryTimeKeluhan(
              #regional: $regional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `
      }
    },
    laporan: {
      bulanan: {
        penurunanJumlahKomplainBulanan: gql`
          query DaftarPenurunanJumlahKomplainBulanan(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            penurunanJumlahKomplainBulanan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              total_gangguan_tahun_ini
              total_keluhan_tahun_ini
              total_gangguan_informasi_tahun_ini
              total_keluhan_informasi_tahun_ini
              total_informasi_tahun_ini
              total_tahun_ini
              total_gangguan_tahun_sebelumnya
              total_keluhan_tahun_sebelumnya
              total_gangguan_informasi_tahun_sebelumnya
              total_keluhan_informasi_tahun_sebelumnya
              total_informasi_tahun_sebelumnya
              total_tahun_sebelumnya
              delta_gangguan
              delta_keluhan
              delta_informasi
              persen_delta_gangguan
              persen_delta_keluhan
              persen_delta_informasi
              persen_delta_total
            }
          }
        `,
        agingComplaintBulanan: gql`
          query DaftarAgingComplaintBulanan(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            agingComplaintBulanan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              avg_durasi_recovery_gangguan
              sla_gangguan
              avg_durasi_recovery_keluhan
              sla_keluhan
              aging_complaint_gangguan
              aging_complaint_keluhan
              avg_aging_complaint
            }
          }
        `,
        energyNotSalesBulanan: gql`
          query DaftarEnergyNotSalesBulanan(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            energyNotSalesBulanan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              terencana
              tidak_terencana
              bencana_alam
              total
              kpi_ens
            }
          }
        `,
        kepatuhandanAkurasiDalamPelaporanBulanan: gql`
          query DaftarkepatuhandanAkurasiDalamPelaporanBulanan(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            kepatuhandanAkurasiDalamPelaporanBulanan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              gangguan_berulang
              gangguan_total
              keluhan_berulang
              keluhan_total
              komplain_pelanggan
            }
          }
        `
      },
      kumulatif: {
        penurunanJumlahKomplainKumulatif: gql`
          query DaftarPenurunanJumlahKomplainKumulatif(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            penurunanJumlahKomplainKumulatif(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              total_gangguan_tahun_ini
              total_keluhan_tahun_ini
              total_gangguan_informasi_tahun_ini
              total_keluhan_informasi_tahun_ini
              total_informasi_tahun_ini
              total_tahun_ini
              total_gangguan_tahun_sebelumnya
              total_keluhan_tahun_sebelumnya
              total_gangguan_informasi_tahun_sebelumnya
              total_keluhan_informasi_tahun_sebelumnya
              total_informasi_tahun_sebelumnya
              total_tahun_sebelumnya
              delta_gangguan
              delta_keluhan
              delta_informasi
              persen_delta_gangguan
              persen_delta_keluhan
              persen_delta_informasi
              persen_delta_total
            }
          }
        `,
        agingComplaintKumulatif: gql`
          query DaftarAgingComplaintKumulatif(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            agingComplaintKumulatif(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              avg_durasi_recovery_gangguan
              sla_gangguan
              avg_durasi_recovery_keluhan
              sla_keluhan
              aging_complaint_gangguan
              aging_complaint_keluhan
              avg_aging_complaint
            }
          }
        `,
        energyNotSalesKumulatif: gql`
          query DaftarEnergyNotSalesKumulatif(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            energyNotSalesKumulatif(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              terencana
              tidak_terencana
              bencana_alam
              total
              kpi_ens
            }
          }
        `,
        kepatuhandanAkurasiDalamPelaporanKumulatif: gql`
          query DaftarkepatuhandanAkurasiDalamPelaporanKumulatif(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            kepatuhandanAkurasiDalamPelaporanKumulatif(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              gangguan_berulang
              gangguan_total
              keluhan_berulang
              keluhan_total
              komplain_pelanggan
            }
          }
        `
      }
    }
  },
  cico: {
    laporanCheckInCheckOut: gql`
      query laporanCheckInCheckOut(
        $dateFrom: Date!
        $dateTo: Date!
        $idPosko: Int
        $idUid: Int
        $idUp3: Int
      ) {
        laporanCheckInCheckOut(
          dateFrom: $dateFrom
          dateTo: $dateTo
          idPosko: $idPosko
          idUid: $idUid
          idUp3: $idUp3
        ) {
          user_regu
          personil_yantek
          jumlah_wo_gangguan_individual
          avg_durasi_wo_gangguan_individual
          avg_rpt_wo_gangguan_individual
          avg_rct_wo_gangguan_individual
          jumlah_wo_penugasan_khusus
          avg_wo_penugasan_khusus
        }
      }
    `
  }
}
